pub struct Telemetry {Show 25 fields
pub paper_id: String,
pub git_sha: String,
pub cmdline: String,
pub host: String,
pub timeout_s: u32,
pub schema_version: u32,
pub wall_us: u64,
pub phase_us: [u64; 17],
pub formulae: u32,
pub math_parse_attempts: u32,
pub math_parse_count: u64,
pub math_parse_buckets: [u32; 9],
pub graphics_assets: u32,
pub graphics_subprocess_count: u32,
pub db_objects: u32,
pub output_bytes: u64,
pub warnings: u32,
pub errors: u32,
pub fatal_errors: u32,
pub external_tool_count: u32,
pub max_rss_kb: u64,
pub child_user_us: u64,
pub child_sys_us: u64,
pub category: String,
pub exit_code: i32,
}Expand description
Per-job telemetry record.
Identifier fields (paper_id, cmdline, host, git_sha) are
filled in by the binary entry point, not by the engine. Phase
wall times and counts are populated by the engine via this
module’s API.
Fields
paper_id: Stringgit_sha: Stringcmdline: Stringhost: Stringtimeout_s: u32schema_version: u32wall_us: u64phase_us: [u64; 17]formulae: u32math_parse_attempts: u32math_parse_count: u64math_parse_buckets: [u32; 9]graphics_assets: u32graphics_subprocess_count: u32db_objects: u32output_bytes: u64warnings: u32errors: u32fatal_errors: u32external_tool_count: u32max_rss_kb: u64child_user_us: u64child_sys_us: u64category: Stringexit_code: i32Implementations